@@ -19,7 +19,7 @@ import os
 
 NHL_COLORS = {
 		'ANA': {'GOAL': '#F47A38', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
-		'ARI': {'GOAL': '#8C2633', 'SHOT': '#111111', 'MISS': '#D3D3D3'},
+		'ARI': {'GOAL': '#E2D6B5', 'SHOT': '#8C2633', 'MISS': '#D3D3D3'},
 		'BOS': {'GOAL': '#FFB81C', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
 		'BUF': {'GOAL': '#FCB514', 'SHOT': '#002654', 'MISS': '#D3D3D3'},
 		'CAR': {'GOAL': '#CC0000', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
@@ -27,25 +27,25 @@ NHL_COLORS = {
 		'CGY': {'GOAL': '#F1BE48', 'SHOT': '#C8102E', 'MISS': '#D3D3D3'},
         'CHI': {'GOAL': '#CF0A2C', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
 		'COL': {'GOAL': '#236192', 'SHOT': '#6F263D', 'MISS': '#D3D3D3'},
-		'DAL': {'GOAL': '#006847', 'SHOT': '#111111', 'MISS': '#D3D3D3'},
-		'DET': {'GOAL': '#CE1126', 'SHOT': '#FFFFFF', 'MISS': '#D3D3D3'},
+		'DAL': {'GOAL': '#8F8F8C', 'SHOT': '#006847', 'MISS': '#D3D3D3'},
+		'DET': {'GOAL': '#FFFFFF', 'SHOT': '#CE1126', 'MISS': '#D3D3D3'},
 		'EDM': {'GOAL': '#FF4C00', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
 		'FLA': {'GOAL': '#C8102E', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
-		'LAK': {'GOAL': '#111111', 'SHOT': '#A2AAAD', 'MISS': '#D3D3D3'},
+		'LAK': {'GOAL': '#A2AAAD', 'SHOT': '#111111', 'MISS': '#D3D3D3'},
 		'MIN': {'GOAL': '#A6192E', 'SHOT': '#154734', 'MISS': '#D3D3D3'},
 		'MTL': {'GOAL': '#AF1E2D', 'SHOT': '#192168', 'MISS': '#D3D3D3'},
 		'NJD': {'GOAL': '#CE1126', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
 		'NSH': {'GOAL': '#FFB81C', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
 		'NYI': {'GOAL': '#F47D30', 'SHOT': '#00539B', 'MISS': '#D3D3D3'},
 		'NYR': {'GOAL': '#CE1126', 'SHOT': '#0038A8', 'MISS': '#D3D3D3'},
-		'OTT': {'GOAL': '#C52032', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
+		'OTT': {'GOAL': '#C2912C', 'SHOT': '#C52032', 'MISS': '#D3D3D3'},
 		'PHI': {'GOAL': '#F74902', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
 		'PIT': {'GOAL': '#FCB514', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
 		'SEA': {'GOAL': '#99D9D9', 'SHOT': '#001628', 'MISS': '#D3D3D3'},
 		'SJS': {'GOAL': '#006D75', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
 		'STL': {'GOAL': '#FCB514', 'SHOT': '#002F87', 'MISS': '#D3D3D3'},
-		'TBL': {'GOAL': '#002868', 'SHOT': '#FFFFFF', 'MISS': '#D3D3D3'},
-		'TOR': {'GOAL': '#00205B', 'SHOT': '#FFFFFF', 'MISS': '#D3D3D3'},
+		'TBL': {'GOAL': '#FFFFFF', 'SHOT': '#002868', 'MISS': '#D3D3D3'},
+		'TOR': {'GOAL': '#002868', 'SHOT': '#00205B', 'MISS': '#D3D3D3'},
 		'VAN': {'GOAL': '#00843D', 'SHOT': '#00205B', 'MISS': '#D3D3D3'},
 		'VGK': {'GOAL': '#B4975A', 'SHOT': '#333F42', 'MISS': '#D3D3D3'},
 		'WSH': {'GOAL': '#C8102E', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
@@ -114,6 +114,8 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
         
     '''
 
+    data = data.copy(deep = True)
+
     if type(strengths) != list:
 
         strengths = convert_to_list(strengths)
@@ -138,6 +140,8 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
     if title == None:
 
+        data.game_date = pd.to_datetime(data.game_date, infer_datetime_format = True)
+
         game_date = data.game_date.iloc[0].strftime('%B %d, %Y')
         home_team = data.home_team.iloc[0]
         home_score = data.home_score.max()
@@ -260,7 +264,7 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
             colors_dict = {x: colors_dict[x] for x in order_list if x in colors_dict.keys()}
 
-            zorder_dict = {'GOAL': 3, 'SHOT': 2, 'MISS': 1}
+            zorder_dict = {'GOAL': 999, 'SHOT': 998, 'MISS': 997}
 
             if team == good_team:
 
@@ -278,16 +282,16 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
                 event_df = plot_df[plot_df.event == result]
 
-                if color == '#FFFFFF' or color == '#A2AAAD':
+                if result == 'GOAL':
 
-                    edge_color = colors[team]['GOAL']
+                    edge_color = colors[team]['SHOT']
 
                 else:
 
                     edge_color = None
 
                 rink.scatter(event_df.norm_coords_x, event_df.norm_coords_y, c = color, label = result, s = 250, alpha = 0.8,
-                    ax = ax, edgecolors = edge_color, is_constrained = True zorder = zorder_dict[result])
+                    ax = ax, edgecolors = edge_color, is_constrained = True, zorder = zorder_dict[result])
 
                 
                 if result != 'GOAL':
@@ -302,11 +306,11 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
             if team == good_team:
 
                 ax.legend(loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
-                            title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray')
+                            title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray').set_zorder(-1)
             if team == bad_team:
 
                 ax.legend(loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
-                            title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray')
+                            title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray').set_zorder(-1)
         if save_img == True:
             
             if os.path.exists('rink_plots') == False:
